Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'blenderkit/paths.py')
-rw-r--r--blenderkit/paths.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/blenderkit/paths.py b/blenderkit/paths.py
index c2d2ab06..c3f92484 100644
--- a/blenderkit/paths.py
+++ b/blenderkit/paths.py
@@ -164,7 +164,7 @@ def get_download_filenames(asset_data):
file_names = []
# fn = asset_data['file_name'].replace('blend_', '')
if asset_data.get('url') is not None:
# this means asset is allready in scene and we don't nedd to check
fn = extract_filename_from_url(asset_data['url'])
fn.replace('_blend', '')
@@ -236,7 +236,7 @@ def get_addon_thumbnail_path(name):
# fpath = os.path.join(p, subpath)
ext = name.split('.')[-1]
next = ''
- if not (ext == 'jpg' or ext == 'png'): # allready has ext?
+ if not (ext == 'jpg' or ext == 'png'): # already has ext?
next = '.jpg'
subpath = "thumbnails" + os.sep + name + next
return os.path.join(script_path, subpath)
@@ -164,7 +164,7 @@ def get_download_filenames(asset_data):
# fn = asset_data['file_name'].replace('blend_', '')
if asset_data.get('url') is not None:
- # this means asset is allready in scene and we don't nedd to check
+ # this means asset is already in scene and we don't nedd to check
fn = extract_filename_from_url(asset_data['url'])
fn.replace('_blend', '')